﻿using System.Windows;
using System.Windows.Controls;
using WpfGeoTagger.ViewModels;

namespace WpfGeoTagger.Views
{
	/// <summary>
	/// MapView.xaml の相互作用ロジック
	/// </summary>
	public partial class MapView : UserControl
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		public MapView()
		{
			this.DataContextChanged += new DependencyPropertyChangedEventHandler( OnDataContextChanged );
			this.InitializeComponent();
		}

		/// <summary>
		/// データ コンテキストが変更された時のイベントです。
		/// </summary>
		/// <param name="sender">イベント送信元。</param>
		/// <param name="e">イベント データ。</param>
		private void OnDataContextChanged( object sender, DependencyPropertyChangedEventArgs e )
		{
			var viewModel = e.NewValue as MapViewModel;
			if( viewModel != null )
			{
				viewModel.InvokeScript += new MapViewModel.InvokeScriptHandler( OnInvokeScript );
			}
		}

		/// <summary>
		/// ブラウザ オブジェクトに読み込まれているスクリプトを実行します。
		/// </summary>
		/// <param name="scriptName">実行するスクリプト関数の名前。</param>
		/// <param name="args">スクリプト関数に渡すパラメータ。</param>
		private void OnInvokeScript( string scriptName, params object[] args )
		{
			this._webBrowser.InvokeScript( scriptName, args );
		}
	}
}
